from setuptools import setup

setup(name='psychic_disco',
      version='0.1.0',
      description='Pythonic Microservices on AWS Lambda',
      url='http://github.com/robertdfrench/psychic-disco',
      author='Robert D. French',
      author_email='robert@robertdfrench.me',
      license='MIT',
      packages=['psychic_disco'],
      zip_safe=False)
